@@ -7,6 +7,7 @@
 
 import sys
 from decimal import Decimal
+from fractions import Fraction
 
 try:
     # For compatibility between Python 2 and 3.
@@ -14,21 +15,6 @@ try:
 except ImportError:
     from io import StringIO
 
-try:
-    # For Python 2.6+.
-    from fractions import Fraction
-except ImportError:
-    Fraction = float
-
-try:
-    # For Python 2.6+.
-    from collections import defaultdict
-    from collections import namedtuple
-except ImportError:
-    # For Python 2.5 support.
-    from .compat_collections import defaultdict
-    from .compat_collections import namedtuple
-
 # Types to check in Python 2/3.
 if sys.version_info[0] == 2:
     int_types = (int, long)
@@ -40,12 +26,6 @@ else:
     str_types = str
 
 
-if sys.version_info < (2, 6, 0):
-    from StringIO import StringIO as BytesIO
-else:
-    from io import BytesIO as BytesIO
-
-
 def force_unicode(string):
     """Return string as a native string"""
     if sys.version_info[0] == 2:
