@@ -84,6 +84,10 @@ class Workbook(xmlwriter.XMLwriter):
         self.default_format_properties = \
             options.get('default_format_properties', {})
 
+        self.max_url_length = options.get('max_url_length', 2079)
+        if self.max_url_length < 255:
+            self.max_url_length = 2079
+
         self.worksheet_meta = WorksheetMeta()
         self.selected = 0
         self.fileclosed = 0
@@ -740,6 +744,7 @@ class Workbook(xmlwriter.XMLwriter):
             'default_url_format': self.default_url_format,
             'excel2003_style': self.excel2003_style,
             'remove_timezone': self.remove_timezone,
+            'max_url_length': self.max_url_length,
         }
 
         worksheet._initialize(init_data)
@@ -1116,11 +1121,6 @@ class Workbook(xmlwriter.XMLwriter):
                 drawing_id += 1
                 has_drawing = True
 
-            # Prepare the worksheet charts.
-            for index in range(chart_count):
-                chart_ref_id += 1
-                sheet._prepare_chart(index, chart_ref_id, drawing_id)
-
             # Prepare the worksheet images.
             for index in range(image_count):
                 filename = sheet.images[index][2]
@@ -1132,6 +1132,11 @@ class Workbook(xmlwriter.XMLwriter):
                 sheet._prepare_image(index, image_ref_id, drawing_id, width,
                                      height, name, image_type, x_dpi, y_dpi)
 
+            # Prepare the worksheet charts.
+            for index in range(chart_count):
+                chart_ref_id += 1
+                sheet._prepare_chart(index, chart_ref_id, drawing_id)
+
             # Prepare the worksheet shapes.
             for index in range(shape_count):
                 sheet._prepare_shape(index, drawing_id)
